"use strict";
/*
 * Copyright (c) 2022.
 * Author Peter Placzek (tada5hi)
 * For the full copyright and license information,
 * view the LICENSE file that was distributed with this source code.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupSocketMiddleware = void 0;
const domains_1 = require("@typescript-auth/domains");
const utils_1 = require("../../utils");
function setupSocketMiddleware(context) {
    const tokenCache = (0, utils_1.initTokenCache)(context.redis, context.redisPrefix);
    const tokenAPIClient = new domains_1.TokenAPI(context.http);
    return (socket, next) => __awaiter(this, void 0, void 0, function* () {
        const { token } = socket.handshake.auth;
        if (!token) {
            return next();
        }
        let data;
        try {
            data = yield (0, utils_1.verifyToken)({
                token,
                tokenCache,
                tokenAPIClient,
            });
        }
        catch (e) {
            return next(e);
        }
        switch (data.target.kind) {
            case 'robot':
                socket.data.robotId = data.target.entity.id;
                socket.data.robot = data.target.entity;
                break;
            case 'user':
                socket.data.userId = data.target.entity.id;
                socket.data.user = data.target.entity;
                break;
        }
        socket.data.token = token;
        socket.data.permissions = data.target.permissions;
        socket.data.ability = new domains_1.AbilityManager(data.target.permissions);
        return next();
    });
}
exports.setupSocketMiddleware = setupSocketMiddleware;
//# sourceMappingURL=module.js.map